interface HtmlLinkDescriptor {
    /**
     * Address of the hyperlink
     */
    href: string;
    /**
     * How the element handles crossorigin requests
     */
    crossOrigin?: "anonymous" | "use-credentials";
    /**
     * Relationship between the document containing the hyperlink and the destination resource
     */
    rel: "alternate" | "dns-prefetch" | "icon" | "manifest" | "modulepreload" | "next" | "pingback" | "preconnect" | "prefetch" | "preload" | "prerender" | "search" | "stylesheet" | string;
    /**
     * Applicable media: "screen", "print", "(max-width: 764px)"
     */
    media?: string;
    /**
     * Integrity metadata used in Subresource Integrity checks
     */
    integrity?: string;
    /**
     * Language of the linked resource
     */
    hrefLang?: string;
    /**
     * Hint for the type of the referenced resource
     */
    type?: string;
    /**
     * Referrer policy for fetches initiated by the element
     */
    referrerPolicy?: "" | "no-referrer" | "no-referrer-when-downgrade" | "same-origin" | "origin" | "strict-origin" | "origin-when-cross-origin" | "strict-origin-when-cross-origin" | "unsafe-url";
    /**
     * Sizes of the icons (for rel="icon")
     */
    sizes?: string;
    /**
     * Images to use in different situations, e.g., high-resolution displays, small monitors, etc. (for rel="preload")
     */
    imagesrcset?: string;
    /**
     * Image sizes for different page layouts (for rel="preload")
     */
    imagesizes?: string;
    /**
     * Potential destination for a preload request (for rel="preload" and rel="modulepreload")
     */
    as?: "audio" | "audioworklet" | "document" | "embed" | "fetch" | "font" | "frame" | "iframe" | "image" | "manifest" | "object" | "paintworklet" | "report" | "script" | "serviceworker" | "sharedworker" | "style" | "track" | "video" | "worker" | "xslt" | string;
    /**
     * Color to use when customizing a site's icon (for rel="mask-icon")
     */
    color?: string;
    /**
     * Whether the link is disabled
     */
    disabled?: boolean;
    /**
     * The title attribute has special semantics on this element: Title of the link; CSS style sheet set name.
     */
    title?: string;
}
interface MetaDescriptor {
    [name: string]: string | string[];
}
/**
 * A function for setting default SEO meta for Remix sites and returns a new
 * function to use on the site's routes.
 *
 * @param defaultConfig - The default configuration object. The returned
 * function will merge its own config with the default config when called on a
 * specific route.
 */
export declare function getSeo(defaultConfig?: SeoConfig): SeoFunction;
export default getSeo;
interface OpenGraphMedia {
    alt: string;
    height?: number;
    secureUrl?: string;
    type?: string;
    url: string;
    width?: number;
}
interface OpenGraphVideoActors {
    profile: string;
    role?: string;
}
interface OpenGraphMeta {
    article?: OpenGraphArticle;
    book?: OpenGraphBook;
    defaultImageHeight?: number;
    defaultImageWidth?: number;
    description?: string;
    images?: OpenGraphMedia[];
    locale?: string;
    profile?: OpenGraphProfile;
    siteName?: string;
    title?: string;
    type?: string;
    url?: string;
    video?: OpenGraphVideo;
    videos?: OpenGraphMedia[];
}
interface OpenGraphProfile {
    firstName?: string;
    lastName?: string;
    gender?: string;
    username?: string;
}
interface OpenGraphBook {
    authors?: string[];
    isbn?: string;
    releaseDate?: string;
    tags?: string[];
}
interface OpenGraphArticle {
    authors?: string[];
    expirationTime?: string;
    modifiedTime?: string;
    publishedTime?: string;
    section?: string;
    tags?: string[];
}
interface OpenGraphVideo {
    actors?: OpenGraphVideoActors[];
    directors?: string[];
    duration?: number;
    releaseDate?: string;
    series?: string;
    tags?: string[];
    writers?: string[];
}
interface TwitterMeta {
    card?: string;
    creator?: string;
    description?: string;
    site?: string;
    title?: string;
    image?: {
        url: string;
        alt: string;
    };
}
interface FacebookMeta {
    appId?: string;
}
interface MobileAlternate {
    media: string;
    href: string;
}
interface LanguageAlternate {
    hrefLang: string;
    href: string;
}
declare type ImagePrevSize = "none" | "standard" | "large";
interface RobotsOptions {
    maxImagePreview?: ImagePrevSize;
    maxSnippet?: number;
    maxVideoPreview?: number;
    noArchive?: boolean;
    noFollow?: boolean;
    noImageIndex?: boolean;
    noIndex?: boolean;
    noSnippet?: boolean;
    noTranslate?: boolean;
    unavailableAfter?: string;
}
export interface SeoConfig {
    bypassTemplate?: boolean;
    canonical?: string;
    defaultTitle?: string;
    description?: string;
    disableGoogleBot?: boolean;
    facebook?: FacebookMeta;
    languageAlternates?: LanguageAlternate[];
    mobileAlternate?: MobileAlternate;
    omitGoogleBotMeta?: boolean;
    openGraph?: OpenGraphMeta;
    robots?: RobotsOptions;
    title?: string;
    titleTemplate?: string;
    twitter?: TwitterMeta;
}
export declare type SeoFunction = (config?: SeoConfig) => [MetaDescriptor, HtmlLinkDescriptor[]];
